Enumeration
AdapToastPriority
since: 1
Members
ADAP_TOAST_PRIORITY_NORMAL-
The toast will be queued if another toast is already displayed.
- Value:
0 - Nickname:
normal - Available since: 1
- Value:
ADAP_TOAST_PRIORITY_HIGH-
The toast will be displayed immediately, pushing the previous toast into the queue instead.
- Value:
1 - Nickname:
high - Available since: 1
- Value: